Learn R Programming

hisemi (version 1.1-0)

logLik.hisemit: Extract the log likelihood from a hisemit object

Description

Extract the log likelihood from a hisemit object.

Usage

# S3 method for hisemit
logLik(object, take.sum = TRUE,...)

Arguments

object

A hisemit object

take.sum

A logical scalar, indicating whether total log likelihood or the log likelihood of each data point should be extracted.

…

Currently not used

Value

An object of class 'logLik'.

References

Long Qu, Dan Nettleton, Jack Dekkers (2012) A hierarchical semiparametric model for incorporating inter-gene relationship information for analysis of genomic data. Biometrics, 68(4):1168-1177

See Also

plot.hisemit, fitted.hisemit, coef.hisemit, vcov.hisemit, residuals.hisemit, logLik.hisemit, confint.hisemit, print.hisemit, penLik.EMNewton